package com.ruoyi.ems.report.service;

import java.util.List;

import com.ruoyi.ems.report.domain.EmsReportPointSteam;

/**
 * 蒸汽整点数据Service接口
 *
 * @author Yinq
 * @date 2024-06-11
 */
public interface IEmsReportPointSteamService {
    /**
     * 查询蒸汽整点数据
     *
     * @param objId 蒸汽整点数据主键
     * @return 蒸汽整点数据
     */
    public EmsReportPointSteam selectEmsReportPointSteamByObjId(Long objId);

    /**
     * 查询蒸汽整点数据列表
     *
     * @param emsReportPointSteam 蒸汽整点数据
     * @return 蒸汽整点数据集合
     */
    public List<EmsReportPointSteam> selectEmsReportPointSteamList(EmsReportPointSteam emsReportPointSteam);

    /**
     * 新增蒸汽整点数据
     *
     * @param emsReportPointSteam 蒸汽整点数据
     * @return 结果
     */
    public int insertEmsReportPointSteam(EmsReportPointSteam emsReportPointSteam);

    /**
     * 修改蒸汽整点数据
     *
     * @param emsReportPointSteam 蒸汽整点数据
     * @return 结果
     */
    public int updateEmsReportPointSteam(EmsReportPointSteam emsReportPointSteam);

    /**
     * 批量删除蒸汽整点数据
     *
     * @param objIds 需要删除的蒸汽整点数据主键集合
     * @return 结果
     */
    public int deleteEmsReportPointSteamByObjIds(Long[] objIds);

    /**
     * 删除蒸汽整点数据信息
     *
     * @param objId 蒸汽整点数据主键
     * @return 结果
     */
    public int deleteEmsReportPointSteamByObjId(Long objId);
}
